@@ -20,22 +20,23 @@
 #ifndef __LIBTRACKER_DATA_H__
 #define __LIBTRACKER_DATA_H__
 
-G_BEGIN_DECLS
-
 #if !defined (TRACKER_ENABLE_INTERNALS) && !defined (TRACKER_COMPILATION)
 #error "TRACKER_ENABLE_INTERNALS not defined, this must be defined to use tracker's internal functions"
 #endif
 
 #define __LIBTRACKER_DATA_INSIDE__
 
+#include "tracker-class.h"
 #include "tracker-data-backup.h"
 #include "tracker-data-manager.h"
 #include "tracker-data-query.h"
 #include "tracker-data-update.h"
+#include "tracker-namespace.h"
+#include "tracker-ontology.h"
+#include "tracker-ontologies.h"
+#include "tracker-property.h"
 #include "tracker-sparql-query.h"
 
 #undef __LIBTRACKER_DATA_INSIDE__
 
-G_END_DECLS
-
 #endif /* __LIBTRACKER_DATA_H__ */
