@@ -2,18 +2,18 @@
  * Copyright (C) 2006, Mr Jamie McCracken (jamiemcc@gnome.org)
  * Copyright (C) 2009, Nokia
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
  * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA  02110-1301, USA.
  */
@@ -21,7 +21,9 @@
 #ifndef __LIBTRACKER_EXTRACT_XMP_H__
 #define __LIBTRACKER_EXTRACT_XMP_H__
 
-#include <glib.h>
+#if !defined (__LIBTRACKER_EXTRACT_INSIDE__) && !defined (TRACKER_COMPILATION)
+#error "only <libtracker-extract/tracker-extract.h> must be included directly."
+#endif
 
 #include <libtracker-client/tracker-sparql-builder.h>
 
@@ -82,13 +84,13 @@ typedef struct {
 	gchar *city;
 } TrackerXmpData;
 
-gboolean tracker_extract_xmp_read  (const gchar          *buffer,
-                                    size_t                len,
-                                    const gchar          *uri,
-                                    TrackerXmpData       *data);
-gboolean tracker_extract_xmp_apply (TrackerSparqlBuilder *metadata,
-                                    const gchar          *uri,
-                                    TrackerXmpData       *data);
+gboolean tracker_xmp_read  (const gchar          *buffer,
+                            size_t                len,
+                            const gchar          *uri,
+                            TrackerXmpData       *data);
+gboolean tracker_xmp_apply (TrackerSparqlBuilder *metadata,
+                            const gchar          *uri,
+                            TrackerXmpData       *data);
 
 G_END_DECLS
 
