@@ -418,7 +418,7 @@ miner_finalize (GObject *object)
 	g_hash_table_unref (miner->private->pauses);
 	g_ptr_array_free (miner->private->async_calls, TRUE);
 
-	tracker_miner_dbus_terminate (miner);
+	tracker_miner_dbus_shutdown (miner);
 
 	G_OBJECT_CLASS (tracker_miner_parent_class)->finalize (object);
 }
@@ -435,8 +435,8 @@ miner_constructed (GObject *object)
 
 static void
 store_name_monitor_cb (TrackerMiner *miner,
-		       const gchar  *name,
-		       gboolean      available)
+                       const gchar  *name,
+                       gboolean      available)
 {
 	GError *error = NULL;
 
@@ -875,7 +875,7 @@ tracker_miner_execute_sparql (TrackerMiner        *miner,
  * Finishes the async operation and returns the query results. If an error
  * occured during the query, @error will be set.
  *
-* Returns: a #GPtrArray with the sparql results which should not be freed.
+ * Returns: a #GPtrArray with the sparql results which should not be freed.
  **/
 const GPtrArray *
 tracker_miner_execute_sparql_finish (TrackerMiner  *miner,
