@@ -27,14 +27,9 @@
 #include <poppler.h>
 
 #include <libtracker-common/tracker-date-time.h>
-#include <libtracker-common/tracker-ontologies.h>
-#include <libtracker-common/tracker-type-utils.h>
 #include <libtracker-common/tracker-utils.h>
-#include <libtracker-common/tracker-type-utils.h>
 
 #include <libtracker-extract/tracker-extract.h>
-#include <libtracker-extract/tracker-xmp.h>
-#include <libtracker-extract/tracker-utils.h>
 
 #include "tracker-main.h"
 
@@ -246,7 +241,7 @@ extract_content (PopplerDocument *document,
 		poppler_page_get_size (page, &rect.x2, &rect.y2);
 
 		text = poppler_page_get_text (page, POPPLER_SELECTION_WORD, &rect);
-		t = tracker_extract_text_normalize (text, n_words - words, &normalized_words);
+		t = tracker_text_normalize (text, n_words - words, &normalized_words);
 
 		words += normalized_words;
 		g_string_append (string, t);
@@ -355,7 +350,7 @@ extract_pdf (const gchar          *uri,
 	}
 
 	if (xml) {
-		tracker_extract_xmp_read (xml, strlen (xml), uri, &xd);
+		tracker_xmp_read (xml, strlen (xml), uri, &xd);
 		g_free (xml);
 		xml = NULL;
 
