@@ -36,27 +36,12 @@
 #include <glib.h>
 #include <glib/gstdio.h>
 
-#include <libtracker-common/tracker-date-time.h>
-#include <libtracker-common/tracker-ontologies.h>
-#include <libtracker-common/tracker-type-utils.h>
 #include <libtracker-common/tracker-file-utils.h>
-#include <libtracker-common/tracker-utils.h>
 
 #include <libtracker-extract/tracker-extract.h>
-#include <libtracker-extract/tracker-xmp.h>
-#include <libtracker-extract/tracker-exif.h>
-#include <libtracker-extract/tracker-utils.h>
 
 #define RFC1123_DATE_FORMAT "%d %B %Y %H:%M:%S %z"
 
-#define NMM_PREFIX TRACKER_NMM_PREFIX
-#define NFO_PREFIX TRACKER_NFO_PREFIX
-#define NIE_PREFIX TRACKER_NIE_PREFIX
-#define DC_PREFIX TRACKER_DC_PREFIX
-#define NCO_PREFIX TRACKER_NCO_PREFIX
-
-#define RDF_PREFIX TRACKER_RDF_PREFIX
-
 typedef struct {
 	gchar *title, *copyright, *creator, *description, *date, *license;
 	gchar *artist;
@@ -98,7 +83,7 @@ rfc1123_to_iso8601_date (gchar *date)
 	/* From: ex. RFC1123 date: "22 May 1997 18:07:10 -0600"
 	 * To  : ex. ISO8601 date: "2007-05-22T18:07:10-0600"
 	 */
-	return tracker_extract_date_format_to_iso8601 (date, RFC1123_DATE_FORMAT);
+	return tracker_date_format_to_iso8601 (date, RFC1123_DATE_FORMAT);
 }
 
 static void
