@@ -19,17 +19,9 @@
 
 #include "config.h"
 
-#include <glib.h>
 #include <gio/gio.h>
 
-#include <libtracker-common/tracker-ontology.h>
-#include <libtracker-common/tracker-type-utils.h>
-#include <libtracker-common/tracker-file-utils.h>
-#include <libtracker-common/tracker-utils.h>
-
 #include <libtracker-extract/tracker-extract.h>
-#include <libtracker-extract/tracker-xmp.h>
-#include <libtracker-extract/tracker-utils.h>
 
 static void extract_xmp (const gchar          *filename,
                          TrackerSparqlBuilder *preupdate,
@@ -153,12 +145,12 @@ extract_xmp (const gchar          *uri,
 		/* If no orig file is found for the sidekick, we use the sidekick to
 		 * describe itself instead, falling back to uri */
 
-		tracker_extract_xmp_read (contents,
-		                          length,
-		                          orig_uri ? orig_uri : uri,
-		                          &xmp_data);
+		tracker_xmp_read (contents,
+		                  length,
+		                  orig_uri ? orig_uri : uri,
+		                  &xmp_data);
 
-		tracker_extract_xmp_apply (metadata, uri, &xmp_data);
+		tracker_xmp_apply (metadata, uri, &xmp_data);
 
 		g_free (orig_uri);
 	}
