@@ -27,45 +27,6 @@
 
 #include <tracker-test-helpers.h>
 
-static void
-test_date_format (void)
-{
-	gchar *result;
-
-	result = tracker_date_format ("");
-	g_assert (result == NULL);
-
-	/* Fails
-	   result = tracker_date_format ("1978"); //Audio.ReleaseDate
-	   g_assert (tracker_test_helpers_cmpstr_equal (result, "1978-01-01T00:00:00"));
-	*/
-
-	result = tracker_date_format ("2008-06-14");
-	g_assert (tracker_test_helpers_cmpstr_equal (result, "2008-06-14T00:00:00"));
-	g_free (result);
-
-	result = tracker_date_format ("20080614000000");
-	g_assert (tracker_test_helpers_cmpstr_equal (result, "2008-06-14T00:00:00"));
-	g_free (result);
-
-	result = tracker_date_format ("20080614000000Z");
-	g_assert (tracker_test_helpers_cmpstr_equal (result, "2008-06-14T00:00:00Z"));
-	g_free (result);
-
-	result = tracker_date_format ("Mon Jun 14 04:20:20 2008"); /* MS Office */
-	g_assert (tracker_test_helpers_cmpstr_equal (result, "2008-06-14T04:20:20"));
-	g_free (result);
-
-	result = tracker_date_format ("2008:06:14 04:20:20"); /* Exif style */
-	g_assert (tracker_test_helpers_cmpstr_equal (result, "2008-06-14T04:20:20"));
-	g_free (result);
-
-	if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDERR)) {
-		result = tracker_date_format (NULL);
-	}
-
-	g_test_trap_assert_failed ();
-}
 
 static void
 test_string_to_date (void)
@@ -75,6 +36,7 @@ test_string_to_date (void)
 	time_t     result_time_t;
 	const gchar  *input = "2008-06-16T11:10:10+0600";
 	gchar  *timezone = g_strdup (g_getenv ("TZ"));
+	GError *error = NULL;
 
 	if (! g_setenv ("TZ", "UTC", TRUE)) {
 		g_test_message ("unable to set timezone, test results are invalid, skipping\n");
@@ -86,7 +48,8 @@ test_string_to_date (void)
 
 	expected = g_date_new_dmy (16, G_DATE_JUNE, 2008);
 
-	result_time_t = tracker_string_to_date (input, NULL);
+	result_time_t = tracker_string_to_date (input, NULL, &error);
+	g_assert_no_error (error);
 
 	result = g_date_new ();
 	g_date_set_time_t (result, result_time_t);
@@ -101,15 +64,21 @@ test_string_to_date (void)
 	g_assert_cmpint (g_date_get_month (expected), ==, g_date_get_month (result));
 
 	if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDERR)) {
-		result_time_t = tracker_string_to_date (NULL, NULL);
+		result_time_t = tracker_string_to_date (NULL, NULL, NULL);
 	}
 	g_test_trap_assert_failed ();
 
-	result_time_t = tracker_string_to_date ("", NULL);
+	result_time_t = tracker_string_to_date ("", NULL, &error);
 	g_assert_cmpint (result_time_t, ==, -1);
+	g_assert_error (error, TRACKER_DATE_ERROR, TRACKER_DATE_ERROR_INVALID_ISO8601);
+	g_error_free (error);
+	error = NULL;
 
-	result_time_t = tracker_string_to_date ("i am not a date", NULL);
+	result_time_t = tracker_string_to_date ("i am not a date", NULL, &error);
 	g_assert_cmpint (result_time_t, ==, -1);
+	g_assert_error (error, TRACKER_DATE_ERROR, TRACKER_DATE_ERROR_INVALID_ISO8601);
+	g_error_free (error);
+	error = NULL;
 
 	/* Fails! Check the code
 	   result_time_t = tracker_string_to_date ("2008-06-32T04:23:10+0000", NULL);
@@ -133,7 +102,11 @@ test_date_to_string (void)
 	original->tm_year = 108;
 	original->tm_isdst = 0;
 
+#if !(defined(__FreeBSD__) || defined(__OpenBSD__))
 	input = mktime (original) - timezone;
+#else
+	input = timegm (original);
+#endif
 
 	result = tracker_date_to_string (input);
 
@@ -415,8 +388,6 @@ main (int argc, char **argv)
 	                 test_int_to_string);
 	g_test_add_func ("/libtracker-common/tracker-type-utils/long_to_string",
 	                 test_long_to_string);
-	g_test_add_func ("/libtracker-common/tracker-type-utils/date_format",
-	                 test_date_format);
 	g_test_add_func ("/libtracker-common/tracker-type-utils/date_to_string",
 	                 test_date_to_string);
 	g_test_add_func ("/libtracker-common/tracker-type-utils/string_to_date",
